searchData={"content_type":"text/markdown","items":[{"doc":"Implements an Überauth strategy for authentication with Zapier.\n\nWhen configuring the strategy in the Überauth provides, you can specify some defaults.\n\n* `default_scope` - The default scopes to request from Zapier when authenticating. Default `profile`.\n* `oauth2_module` - The OAuth2 module to use for authentication. Default `Ueberauth.Strategy.Zapier.OAuth`.\n\n```elixir\n\nconfig :ueberauth, Ueberauth,\n  providers: [\n    zapier: {Ueberauth.Strategy.Zapier, [default_scope: \"profile\"]}\n  ]\n```","ref":"Ueberauth.Strategy.Zapier.html","title":"Ueberauth.Strategy.Zapier","type":"module"},{"doc":"Includes the credentials from the Zapier response.","ref":"Ueberauth.Strategy.Zapier.html#credentials/1","title":"Ueberauth.Strategy.Zapier.credentials/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Zapier.html#default_options/0","title":"Ueberauth.Strategy.Zapier.default_options/0","type":"function"},{"doc":"Stores the raw information (including the token and user) in the `Ueberauth.Auth.Extra` struct.","ref":"Ueberauth.Strategy.Zapier.html#extra/1","title":"Ueberauth.Strategy.Zapier.extra/1","type":"function"},{"doc":"Cleans up the private area of the connection used for passing the raw response during the callback.","ref":"Ueberauth.Strategy.Zapier.html#handle_cleanup!/1","title":"Ueberauth.Strategy.Zapier.handle_cleanup!/1","type":"function"},{"doc":"Handles initial redirect to the Zapier OAuth authorization page.\n\nTo customize the scopes, set the `:default_scope` option in your configuration.","ref":"Ueberauth.Strategy.Zapier.html#handle_request!/1","title":"Ueberauth.Strategy.Zapier.handle_request!/1","type":"function"},{"doc":"Fetches the user information from the Zapier response to populate the `Ueberauth.Auth.Info` struct.","ref":"Ueberauth.Strategy.Zapier.html#info/1","title":"Ueberauth.Strategy.Zapier.info/1","type":"function"},{"doc":"Fetches the uid field from the Zapier response.","ref":"Ueberauth.Strategy.Zapier.html#uid/1","title":"Ueberauth.Strategy.Zapier.uid/1","type":"function"},{"doc":"OAuth2 for Zapier.\n\nThis module defines the OAuth2 client and necessary functions to handle\nauthorization and token retrieval for Zapier's OAuth2 authentication.\n\nAdd `client_id` and `client_secret` to your configuration to use this strategy:\n\n```elixir\nconfig :ueberauth, Ueberauth.Strategy.Zapier.OAuth,\n  client_id: System.get_env(\"ZAPIER_CLIENT_ID\"),\n  client_secret: System.get_env(\"ZAPIER_CLIENT_SECRET\")\n```","ref":"Ueberauth.Strategy.Zapier.OAuth.html","title":"Ueberauth.Strategy.Zapier.OAuth","type":"module"},{"doc":"","ref":"Ueberauth.Strategy.Zapier.OAuth.html#authorize_url/2","title":"Ueberauth.Strategy.Zapier.OAuth.authorize_url/2","type":"function"},{"doc":"Provides the authorize url for the request phase of Ueberauth.\n\nNo need to call this usually.","ref":"Ueberauth.Strategy.Zapier.OAuth.html#authorize_url!/2","title":"Ueberauth.Strategy.Zapier.OAuth.authorize_url!/2","type":"function"},{"doc":"Construct a client for requests to Zapier.\n\nThis will be setup automatically for you in `Ueberauth.Strategy.Zapier`.\n\nThese options are only useful for usage outside the normal callback phase of Ueberauth.","ref":"Ueberauth.Strategy.Zapier.OAuth.html#client/1","title":"Ueberauth.Strategy.Zapier.OAuth.client/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Zapier.OAuth.html#get/4","title":"Ueberauth.Strategy.Zapier.OAuth.get/4","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Zapier.OAuth.html#get_access_token/2","title":"Ueberauth.Strategy.Zapier.OAuth.get_access_token/2","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Zapier.OAuth.html#get_token/3","title":"Ueberauth.Strategy.Zapier.OAuth.get_token/3","type":"function"},{"doc":"# Überauth Zapier\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ueberauth_zapier.svg)](https://hex.pm/packages/ueberauth_zapier)\n[![Documentation](https://img.shields.io/badge/hex-docs-blue)](https://hexdocs.pm/ueberauth_zapier)\n\n> Ueberauth plugin for Zapier OAuth.","ref":"readme.html","title":"Überauth Zapier","type":"extras"},{"doc":"[Ueberauth](https://github.com/ueberauth/ueberauth) is an authentication framework for Elixir applications that specializes in [OAuth](https://oauth.net/). This library is one of many [plugins](https://github.com/ueberauth/ueberauth/wiki/List-of-Strategies) (called Strategies) that allow Ueberauth to integrate with different identity providers. Specifically, this one implements an OAuth integration with Zapier.","ref":"readme.html#what-is-this","title":"What is this? - Überauth Zapier","type":"extras"},{"doc":"1. Setup your application integration in Zapier Development Dashboard https://developer.zapier.com/\n\n2. Add `:ueberauth_zapier` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [\n        {:ueberauth, \"~> 0.10\"},\n        {:oauth2, \"~> 2.1\"},\n        {:ueberauth_zapier, \"~> 0.1.1\"}\n      ]\n    end\n    ```\n\n3. Add Zapier to your Überauth configuration:\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        # Configure Zapier OAuth strategy with 'profile' scope to get user profile.\n        # Additional scopes can be added as needed, separated by spaces\n        zapier: {Ueberauth.Strategy.Zapier, [default_scope: \"profile\"]},\n      ]\n    ```\n\n4.  Update your provider configuration:\n\n    ```elixir\n    config :ueberauth, Ueberauth.Strategy.Zapier.OAuth,\n      client_id: System.get_env(\"ZAPIER_CLIENT_ID\"),\n      client_secret: System.get_env(\"ZAPIER_CLIENT_SECRET\")\n    ```\n\n5.  Include the Überauth plug in your router pipeline:\n\n    ```elixir\n    defmodule TestZapierWeb.Router do\n      use TestZapierWeb, :router\n\n      pipeline :browser do\n        plug Ueberauth\n        ...\n       end\n    end\n    ```\n\n6.  Add the request and callback routes:\n\n    ```elixir\n    scope \"/auth\", TestZapierWeb do\n      pipe_through :browser\n\n      get \"/:provider\", AuthController, :request\n      get \"/:provider/callback\", AuthController, :callback\n    end\n    ```\n\n7. Create a new controller or use an existing controller that implements callbacks to deal with `Ueberauth.Auth` and `Ueberauth.Failure` responses from Zapier.\n\n    ```elixir\n      defmodule TestZapierWeb.AuthController do\n        use TestZapierWeb, :controller\n\n        def callback(%{assigns: %{ueberauth_failure: _fails}} = conn, _params) do\n          conn\n          |> put_flash(:error, \"Failed to authenticate.\")\n          |> redirect(to: \"/\")\n        end\n\n        def callback(%{assigns: %{ueberauth_auth: auth}} = conn, _params) do\n          case UserFromAuth.find_or_create(auth) do\n            {:ok, user} ->\n              conn\n              |> put_flash(:info, \"Successfully authenticated.\")\n              |> put_session(:current_user, user)\n              |> configure_session(renew: true)\n              |> redirect(to: \"/\")\n\n            {:error, reason} ->\n              conn\n              |> put_flash(:error, reason)\n              |> redirect(to: \"/\")\n          end\n        end\n      end\n    ```","ref":"readme.html#installation","title":"Installation - Überauth Zapier","type":"extras"},{"doc":"Once your setup, you can initiate auth using the following URL, unless you changed the routes from the guide:\n\n    /auth/zapier","ref":"readme.html#calling","title":"Calling - Überauth Zapier","type":"extras"},{"doc":"The docs can be found at [ueberauth_zapier][package-docs] on [Hex Docs][hex-docs].\n\n[hex-docs]: https://hexdocs.pm\n[package-docs]: https://hexdocs.pm/ueberauth_zapier","ref":"readme.html#documentation","title":"Documentation - Überauth Zapier","type":"extras"}],"producer":{"name":"ex_doc","version":"0.35.1"},"proglang":"elixir"}